@@ -52,32 +52,32 @@ PdsListVector *pds_list_vector_new(void)
  *  \brief Agrega un elemento a la cima de la lista.
  *  \param[in,out] Lprev El nodo de la cima de la lista.
  *  \param[in] N La cantidad de elementos del vector.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el último nodo da error
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el último nodo da error
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_push(PdsListVector **Lprev,PdsRaNatural N)
 {
 	PdsListVector *L=NULL;
 
-	if((*Lprev)==NULL)		return FALSE;
-	if((*Lprev)->AddNext!=NULL)	return FALSE;
+	if((*Lprev)==NULL)		return PDS_WRONG;
+	if((*Lprev)->AddNext!=NULL)	return PDS_WRONG;
 
 	if((*Lprev)->V==NULL)
 	{
 		(*Lprev)->V=pds_vector_new(N);
-		return TRUE;
+		return PDS_OK;
 	}
 	else
 	{
 		L=(PdsListVector *)calloc(1,sizeof(PdsListVector));
-		if(L==NULL)	return FALSE;
+		if(L==NULL)	return PDS_WRONG;
 	
-		L->AddPrev=(*Lprev);
+		L->AddPrev=*Lprev;
 		L->V=pds_vector_new(N);
 		if(L->V==NULL)
 		{
 			free(L);
-			return FALSE;
+			return PDS_WRONG;
 		}
 		L->AddNext=NULL;
 
@@ -85,29 +85,29 @@ int pds_list_vector_push(PdsListVector **Lprev,PdsRaNatural N)
 
 		(*Lprev)=L;
 	
-		return TRUE;
+		return PDS_OK;
 	}
 }
 
 
 /** \fn int pds_list_vector_pop(PdsListVector **L)
- *  \brief Quita un elemento de la lista. Si no hay elementos retorna FALSE.
+ *  \brief Quita un elemento de la lista. Si no hay elementos retorna PDS_WRONG.
  *  \param[in,out] L El nodo de la cima de la lista.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el último nodo da error
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el último nodo da error
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_pop(PdsListVector **L)
 {
 	PdsListVector *Lprev=NULL;
 
-	if((*L)==NULL)		return FALSE;
-	if((*L)->AddNext!=NULL)	return FALSE;
+	if((*L)==NULL)		return PDS_WRONG;
+	if((*L)->AddNext!=NULL)	return PDS_WRONG;
 	
 	if((*L)->AddPrev==NULL)
 	{
 		if((*L)->V==NULL)
 		{
-			return FALSE;
+			return PDS_WRONG;
 		}
 		else
 		{
@@ -115,12 +115,12 @@ int pds_list_vector_pop(PdsListVector **L)
 			pds_vector_free((*L)->V);
 			(*L)->V=NULL;
 			(*L)->AddPrev=NULL;
-			return TRUE;
+			return PDS_OK;
 		}
 	}
 	else
 	{
-		Lprev=(*L)->AddPrev;
+		Lprev=(PdsListVector*)((*L)->AddPrev);
 	
 		(*L)->AddNext=NULL;
 		pds_vector_free((*L)->V);
@@ -130,35 +130,35 @@ int pds_list_vector_pop(PdsListVector **L)
 
 		(*L)=Lprev;
 		(*L)->AddNext=NULL;
-		return TRUE;
+		return PDS_OK;
 	}
 }
 
 
 /** \fn int pds_list_vector_shift(PdsListVector **L)
- *  \brief Quita el elemento inicial;mas antiguo; de la lista, si no hay elementos retorna FALSE.
+ *  \brief Quita el elemento inicial;mas antiguo; de la lista, si no hay elementos retorna PDS_WRONG.
  *  \param[in,out] L El primer nodo de la lista.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el primer nodo da error.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el primer nodo da error.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_shift(PdsListVector **L)
 {
 	PdsListVector *Lnext=NULL;
 
-	if((*L)==NULL)		return FALSE;
-	if((*L)->AddPrev!=NULL)	return FALSE;
+	if((*L)==NULL)		return PDS_WRONG;
+	if((*L)->AddPrev!=NULL)	return PDS_WRONG;
 	
 	if((*L)->AddNext==NULL)
 	{
 		if((*L)->V==NULL)
 		{
-			return FALSE;
+			return PDS_WRONG;
 		}
 		else
 		{
 			pds_vector_free((*L)->V);
 			(*L)->V=NULL;
-			return TRUE;
+			return PDS_OK;
 		}
 	}
 	else
@@ -172,7 +172,7 @@ int pds_list_vector_shift(PdsListVector **L)
 
 		(*L)=Lnext;
 		(*L)->AddPrev=NULL;
-		return TRUE;
+		return PDS_OK;
 	}
 }
 
@@ -181,32 +181,32 @@ int pds_list_vector_shift(PdsListVector **L)
  *  \brief Agrega un elemento al inicio de la lista.
  *  \param[in,out] Lnext El primer nodo de la lista.
  *  \param[in] N La cantidad de elementos del vector.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el primer nodo da error.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el primer nodo da error.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_unshift(PdsListVector **Lnext,PdsRaNatural N)
 {
 	PdsListVector *L=NULL;
 
-	if((*Lnext)==NULL)		return FALSE;
-	if((*Lnext)->AddPrev!=NULL)	return FALSE;
+	if((*Lnext)==NULL)		return PDS_WRONG;
+	if((*Lnext)->AddPrev!=NULL)	return PDS_WRONG;
 
 	if((*Lnext)->V==NULL)
 	{
 		(*Lnext)->V=pds_vector_new(N);
-		return TRUE;
+		return PDS_OK;
 	}
 	else
 	{
 		L=(PdsListVector *)calloc(1,sizeof(PdsListVector));
-		if(L==NULL)	return FALSE;
+		if(L==NULL)	return PDS_WRONG;
 	
-		L->AddNext=(*Lnext);
+		L->AddNext=*Lnext;
 		L->V=pds_vector_new(N);
 		if(L->V==NULL)
 		{
 			free(L);
-			return FALSE;
+			return PDS_WRONG;
 		}
 		L->AddPrev=NULL;
 
@@ -214,7 +214,7 @@ int pds_list_vector_unshift(PdsListVector **Lnext,PdsRaNatural N)
 
 		(*Lnext)=L;
 	
-		return TRUE;
+		return PDS_OK;
 	}
 }
 
@@ -222,48 +222,48 @@ int pds_list_vector_unshift(PdsListVector **Lnext,PdsRaNatural N)
 /** \fn int pds_list_vector_top(PdsListVector **L)
  *  \brief Busca el elemento final; superior; de la lista.
  *  \param[in,out] L Un nodo de la lista, en donde se cargará el último nodo.
- *  \return TRUE si todo fue bien o FALSE si no. 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. 
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_top(PdsListVector **L)
 {
-	if((*L)==NULL)	return FALSE;
+	if((*L)==NULL)	return PDS_WRONG;
 
 	while((*L)->AddNext!=NULL)
 	{
 		(*L)=(*L)->AddNext;
 	}
-	return TRUE;
+	return PDS_OK;
 }
 
 
 /** \fn int pds_list_vector_bottom(PdsListVector **L)
  *  \brief Busca el elemento inicial; inferior; de la lista.
  *  \param[in,out] L Un nodo de la lista, en donde se cargará el primer nodo.
- *  \return TRUE si todo fue bien o FALSE si no. 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. 
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_bottom(PdsListVector **L)
 {
-	if((*L)==NULL)	return FALSE;
+	if((*L)==NULL)	return PDS_WRONG;
 
 	while((*L)->AddPrev!=NULL)
 	{
 		(*L)=(*L)->AddPrev;
 	}
-	return TRUE;
+	return PDS_OK;
 }
 
 
 /** \fn int pds_list_vector_printf(const PdsListVector *L)
  *  \brief Imprime en pantalla los datos de un nodo de tipo puntero PdsListVector.
  *  \param[in] L El nodo a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_printf(const PdsListVector *L)
 {
-	if(L==NULL)		return FALSE;
+	if(L==NULL)		return PDS_WRONG;
 
 	printf("%p\t",L);
 	printf("AddPrev : %p\n",L->AddPrev);
@@ -275,40 +275,40 @@ int pds_list_vector_printf(const PdsListVector *L)
 	else		printf("\t\tV       :\n");
 	printf("\t\tAddNext : %p\n",L->AddNext);
 	
-	return TRUE;
+	return PDS_OK;
 }
 
 
 /** \fn int pds_list_vector_all_printf(const PdsListVector *L)
  *  \brief Imprime en pantalla todos los datos de la lista.
  *  \param[in] L Un nodo de la lista a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_all_printf(const PdsListVector *L)
 {
 	PdsListVector *Lbottom=NULL;
-	PdsRaNatural i;
+	//PdsRaNatural i;
 	int id;
 
-	if(L==NULL)		return FALSE;
+	if(L==NULL)		return PDS_WRONG;
 
 	Lbottom=(PdsListVector *)L;
 
 	id=pds_list_vector_bottom(&Lbottom);
-	if(id==FALSE)	return FALSE;
+	if(id==PDS_WRONG)	return PDS_WRONG;
 
 	
 	while(1)
 	{
 		id=pds_list_vector_printf(Lbottom);
-		if(id==FALSE)	return FALSE;
+		if(id==PDS_WRONG)	return PDS_WRONG;
 
 		if(Lbottom->AddNext!=NULL)	Lbottom=Lbottom->AddNext;
 		else				break;
 	}
 		
-	return TRUE;
+	return PDS_OK;
 }
 
 
@@ -328,7 +328,7 @@ void pds_list_vector_free(PdsListVector *L)
 		Lbottom=L;
 
 		id=pds_list_vector_bottom(&Lbottom);
-		if(id==TRUE)
+		if(id==PDS_OK)
 		{
 			while(1)
 			{
@@ -358,7 +358,7 @@ void pds_list_vector_destroy(PdsListVector **L)
 		Lbottom=*L;
 
 		id=pds_list_vector_bottom(&Lbottom);
-		if(id==TRUE)
+		if(id==PDS_OK)
 		{
 			while(1)
 			{
