@@ -19,92 +19,84 @@
  * MA 02110-1301, USA.
  * 
  */
-
-#include <math.h>
 #include <pds/pdsrautils.h>
+#include <math.h>
+
 
 
 
 /** \fn int pds_load_number_of_columns_and_lines(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl)
  *  \brief Encuentra el número de columnas y de lineas dentro de un archivo.
  *  si el número de columnas no es constante dentro del archivo, la función 
- *  retorna FALSE, y carga en nc y nl la posición aproximada del error.
+ *  retorna PDS_WRONG, y carga en nc y nl la posición aproximada del error.
  *  Al terminar coloca el fd en el inicio del archivo.
  *  Usa TAB como delimitarode columna y un salto de linea como delimitador de fila.
  *  \param[in] fd Descriptor del fichero.
  *  \param[out] nc Número de columnas en el archivo.
  *  \param[out] nl Número de lineas en el archivo.
- *  \return TRUE si todo fue bien o FALSE si no. (ej. fd==NULL)
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. (ej. fd==NULL)
  *  \ingroup PdsRaUtilsGroup
  */
 int pds_load_number_of_columns_and_lines(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl)
 {
-	PdsRaNatural i,ncol,ncold,nlin;
+	PdsRaNatural ncol,ncol_total,last_ncol,nlin;
 	char x[__MAX_CHAR_DATA_SIZE__],c;
-	fpos_t *pos=NULL;
+	//fpos_t *pos=NULL;
 	char TAB='\t';
-	char NL='\n';
+	char SPACE=' ';
 	int tmp;
 
-	if(nc==NULL)	return FALSE;
-	if(nl==NULL)	return FALSE;
-	if(fd==NULL)	return FALSE;
-
+	if(nc==NULL)	return PDS_WRONG;
+	if(nl==NULL)	return PDS_WRONG;
+	if(fd==NULL)	return PDS_WRONG;
+    
+    ncol_total=0;
 	nlin=0;
 	ncol=0;
+    last_ncol=0;
 	while(feof(fd)==0)
 	{
 		x[0]=0;
 
 		tmp=fscanf(fd,"%s",x);
-		c=(char)fgetc(fd);	
+		c=(char)fgetc(fd);
 
 
-		if(strlen(x)==0)	
-		{
-			if(ncol==0)	break;
+        if((strlen(x)==0)||(tmp!=1)) break;
 
-			ncol=ncol-1;
+        ncol=ncol+1;
+        last_ncol=ncol;
+        if(nlin==0) ncol_total=ncol; 
 
-			if( (ncol!=ncold)&(nlin!=1) )
-			{
-				*nl=nlin+1;
-				*nc=ncol+1;
-				rewind(fd);
-				return FALSE;
-			}
-		}
+        if( (c!=TAB)&&(c!=SPACE) )
+        {
+            nlin=nlin+1;
 
-		if(c==TAB)	
-		{
-			ncol=ncol+1;
-		}
+            if(ncol_total!=ncol)
+            {
+                *nl=nlin-1;
+                *nc=ncol-1;
+                return PDS_WRONG;
+            }
+            ncol=0;
+        }
+
+        //printf("TMP:%d\tS:[%s]\tC:[%d]\tnl:%d\tnc:%d\tlast_nc:%d\n",tmp,x,c,nlin,ncol,last_ncol);	
 
-		if(c==NL)	
-		{
-			
-			nlin=nlin+1;
-			if( (ncol!=ncold)&(nlin!=1) )
-			{
-				*nl=nlin;
-				*nc=ncol+1;
-				rewind(fd);
-				return FALSE;
-			}
-			ncold=ncol;
-			ncol=0;
-		}
 	}
 
 	rewind(fd);
 
-	if(ncol==0)	FALSE;
-	if(nlin==0)	FALSE;
 
 	*nl=nlin;
-	*nc=ncold+1;
+	*nc=ncol_total;
 
-	return TRUE;
+    if(last_ncol!=ncol_total)   return PDS_WRONG;
+	if(ncol_total==0)	return PDS_WRONG;
+	if(nlin==0)	        return PDS_WRONG;
+
+
+	return PDS_OK;
 }
 
 /** \fn int pds_load_number_of_elements(FILE *fd,PdsRaNatural *n)
@@ -113,17 +105,17 @@ int pds_load_number_of_columns_and_lines(FILE *fd,PdsRaNatural *nc,PdsRaNatural
  *  Usa TAB o un salto de linea como delimitador de elemento.
  *  \param[in] fd Descriptor del fichero.
  *  \param[out] n Número de elementos en el archivo.
- *  \return TRUE si todo fue bien o FALSE si no. (ej. fd==NULL)
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. (ej. fd==NULL)
  *  \ingroup PdsRaUtilsGroup
  */
 int pds_load_number_of_elements(FILE *fd,PdsRaNatural *n)
 {
-	PdsRaNatural i;
+	//PdsRaNatural i;
 	int tmp;
 	char x[__MAX_CHAR_DATA_SIZE__];
 
-	if(fd==NULL)	return FALSE;
-	if( n==NULL)	return FALSE;
+	if(fd==NULL)	return PDS_WRONG;
+	if( n==NULL)	return PDS_WRONG;
 
 	*n=0;
 
@@ -131,13 +123,13 @@ int pds_load_number_of_elements(FILE *fd,PdsRaNatural *n)
 	{
 		x[0]=0;
 		tmp=fscanf(fd,"%s",x);
-		if(strlen(x)==0)	break;
+		if((strlen(x)==0)||(tmp!=1))	break;
 		(*n)++;
 	}
 	rewind(fd);
-	if(*n==0)	FALSE;
+	if(*n==0)	return PDS_WRONG;
 
-	return TRUE;
+	return PDS_OK;
 }
 
 
