@@ -40,13 +40,7 @@ extern "C" {
 #include <stdlib.h>
 #include <pds/pdsraglobal.h>
 
-#ifndef TRUE
-	#define TRUE 1
-#endif
 
-#ifndef FALSE
-	#define FALSE 0
-#endif
 
 /** \defgroup PdsLVectorGroup Módulo PdsListVector.
  *  \brief Funciones que trabajan con listas vectores.
@@ -56,6 +50,24 @@ extern "C" {
  * @{
  */
 
+#ifndef PDS_OK
+/*!
+  \def PDS_OK
+  Valor retornado en caso de exito, este es un valor diferente que cero.
+*/
+	#define PDS_OK 1
+#endif
+
+#ifndef PDS_WRONG
+/*!
+  \def PDS_WRONG
+  Valor retornado en caso de fracaso, este valor es igual a cero.
+*/
+	#define PDS_WRONG 0
+#endif
+
+typedef struct PdsListVector PdsListVector;
+
 /*! \struct PdsListVector
  *  \brief La estructura tipo  PdsListVector .
  *  Esta estructura genera una doblemente enlazada lista de vectores.
@@ -63,15 +75,22 @@ extern "C" {
  *  \ingroup PdsListVectorGroup
  *  \author Fernando Pujaico Rivera
  */
-typedef struct PdsListVector
+struct PdsListVector
 {
 	// Dirección del nodo anterios de la lista.
-	struct PdsListVector *AddPrev;
+	PdsListVector *AddPrev;
 	// Vector real asociado; dentro;del nodo.
 	PdsVector *V;
 	// Direccion del nodo siguiente en la lista.
-	struct PdsListVector *AddNext;
-}PdsListVector;
+	PdsListVector *AddNext;
+};
+
+
+
+/** @name pds_list_vector_new
+ *  Creando una lista de vectores
+ * @{
+ */
 
 /** \fn PdsListVector *pds_list_vector_new(void)
  *  \brief Crea una lista de tipo PdsListVector vacia.
@@ -81,29 +100,36 @@ typedef struct PdsListVector
 PdsListVector *pds_list_vector_new(void);
 
 
+//@}
+
+/** @name pds_list_vector_<methods>
+ *  Funciones con metodos para lista de vectores
+ * @{
+ */
+
 /** \fn int pds_list_vector_push(PdsListVector **Lprev,PdsRaNatural N)
  *  \brief Agrega un elemento a la cima de la lista.
  *  \param[in,out] Lprev El nodo de la cima de la lista.
  *  \param[in] N La cantidad de elementos del vector.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el último nodo da error
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el último nodo da error
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_push(PdsListVector **Lprev,PdsRaNatural N);
 
 
 /** \fn int pds_list_vector_pop(PdsListVector **L)
- *  \brief Quita un elemento de la lista. Si no hay elementos retorna FALSE.
+ *  \brief Quita un elemento de la lista. Si no hay elementos retorna PDS_WRONG.
  *  \param[in,out] L El nodo de la cima de la lista.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el último nodo da error
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el último nodo da error
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_pop(PdsListVector **L);
 
 
 /** \fn int pds_list_vector_shift(PdsListVector **L)
- *  \brief Quita el elemento inicial;mas antiguo; de la lista, si no hay elementos retorna FALSE.
+ *  \brief Quita el elemento inicial;mas antiguo; de la lista, si no hay elementos retorna PDS_WRONG.
  *  \param[in,out] L El primer nodo de la lista.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el primer nodo da error.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el primer nodo da error.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_shift(PdsListVector **L);
@@ -113,7 +139,7 @@ int pds_list_vector_shift(PdsListVector **L);
  *  \brief Agrega un elemento al inicio de la lista.
  *  \param[in,out] Lnext El primer nodo de la lista.
  *  \param[in] N La cantidad de elementos del vector.
- *  \return TRUE si todo fue bien o FALSE si no. Si no le das el primer nodo da error.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. Si no le das el primer nodo da error.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_unshift(PdsListVector **Lnext,PdsRaNatural N);
@@ -122,7 +148,7 @@ int pds_list_vector_unshift(PdsListVector **Lnext,PdsRaNatural N);
 /** \fn int pds_list_vector_top(PdsListVector **L)
  *  \brief Busca el elemento final; superior; de la lista.
  *  \param[in,out] L Un nodo de la lista, en donde se cargará el último nodo.
- *  \return TRUE si todo fue bien o FALSE si no. 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. 
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_top(PdsListVector **L);
@@ -131,16 +157,22 @@ int pds_list_vector_top(PdsListVector **L);
 /** \fn int pds_list_vector_bottom(PdsListVector **L)
  *  \brief Busca el elemento inicial; inferior; de la lista.
  *  \param[in,out] L Un nodo de la lista, en donde se cargará el primer nodo.
- *  \return TRUE si todo fue bien o FALSE si no. 
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no. 
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_bottom(PdsListVector **L);
 
+//@}
+
+/** @name pds_list_vector_<printf>
+ *  Funciones para mostrar datos de lista de vectores
+ * @{
+ */
 
 /** \fn int pds_list_vector_printf(const PdsListVector *L)
  *  \brief Imprime en pantalla los datos de un nodo de tipo puntero PdsListVector.
  *  \param[in] L El nodo a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_printf(const PdsListVector *L);
@@ -149,12 +181,19 @@ int pds_list_vector_printf(const PdsListVector *L);
 /** \fn int pds_list_vector_all_printf(const PdsListVector *L)
  *  \brief Imprime en pantalla todos los datos de la lista.
  *  \param[in] L Un nodo de la lista a imprimir en pantalla.
- *  \return TRUE si todo fue bien o FALSE si no.
+ *  \return PDS_OK si todo fue bien o PDS_WRONG si no.
  *  \ingroup PdsListVectorGroup
  */
 int pds_list_vector_all_printf(const PdsListVector *L);
 
 
+//@}
+
+/** @name pds_list_vector_<free>
+ *  Liberando memoria.
+ * @{
+ */
+
 /** \fn void pds_list_vector_free(PdsListVector *L)
  *  \brief Libera una lista entera de tipo puntero PdsListVector. 
  *  \param[in,out] L La lista a liberar.
@@ -172,6 +211,8 @@ void pds_list_vector_free(PdsListVector *L);
  */
 void pds_list_vector_destroy(PdsListVector **L);
 
+//@}
+
 /**
  * @}
  */
