@@ -41,9 +41,10 @@
 #define __PDSRA_H__
 
 #include <pds/pdsrautils.h>
+#include <pds/pdscolormap.h>
 #include <pds/pdsmatrix.h>
 #include <pds/pdsvector.h>
 #include <pds/pdslvector.h>
-#include <pds/pdsfifo.h>
+#include <pds/pdsregionrect.h>
 
 #endif /* __PDSRA_H__ */
